@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Get XML.
 has xml => (
@@ -81,7 +81,7 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
 =item C<get_lines()>
 
  Get lines in metro map.
- Returns reference to array with Map::Tube::Line objects.
+ Returns reference to unsorted array with Map::Tube::Line objects.
 
 =item C<get_node_by_id($station_id)>
 
@@ -221,6 +221,59 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
  # U-Bahn-Linie U4
  # U-Bahn-Linie U6
 
+=head1 EXAMPLE5
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Vienna;
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 line\n";
+         exit 1;
+ }
+ my $line = $ARGV[0];
+
+ # Object.
+ my $obj = Map::Tube::Vienna->new;
+
+ # Get stations for line.
+ my $stations_ar = $obj->get_stations($line);
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } @{$stations_ar};
+
+ # Output:
+ # Usage: __PROG__ line
+
+ # Output with 'foo' argument.
+ # Map::Tube::get_stations(): ERROR: Invalid Line Name [foo]. (status: 105) file __PROG__ on line __LINE__
+
+ # Output with 'U-Bahn-Linie U1' argument.
+ # Reumannplatz
+ # Keplerplatz
+ # Südtiroler Platz-Hauptbahnhof
+ # Taubstummengasse
+ # Karlsplatz
+ # Stephansplatz
+ # Schwedenplatz
+ # Nestroyplatz
+ # Praterstern
+ # Vorgartenstraße
+ # Donauinsel
+ # Kaisermühlen
+ # Alte Donau
+ # Kagran
+ # Kagraner Platz
+ # Rennbahnweg
+ # Aderklaaer Straße
+ # Großfeldsiedlung
+ # Leopoldau
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -264,6 +317,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
